@@ -1,6 +1,6 @@
 calc_stats <-
 function(epsp, stat){
-  stopifnot(is.numeric(epsp))
+  stopifnot(is.numeric(epsp), is.vector(epsp))
   output <- numeric(length(stat))
   for(i in seq_along(stat)){
     output[[i]] <- get(stat[i])(epsp)
