@@ -3,12 +3,8 @@ calc_theta_hat <-
     # optimization_args should already be formatted by
     # validate_args_distfreereg_...().
     stopifnot(is.function(ftheta), is.function(optimization_fun), is.numeric(Y),
-              is.numeric(Q))
-    if(is.matrix(Q)){
-      target <- function(theta) crossprod(Q %*% (Y - ftheta(theta)))
-    } else {
-      target <- function(theta) crossprod(Q * (Y - ftheta(theta)))
-    }
+              is.vector(Y), is.numeric(Q) || is.list(Q))
+    target <- function(theta) crossprod(covprod(Q, (Y - ftheta(theta))))
     # Add function to optimize to argument list.
     optimization_args[[fun_to_optimize_arg]] <- target
     optimization_output <-
