@@ -3,5 +3,7 @@ default_distfreereg_tol <- function(){
        solve_tol = .Machine[["double.eps"]],
        qr_tol = sqrt(.Machine[["double.eps"]]),
        orth_tol = sqrt(.Machine[["double.eps"]]),
-       trans_tol = sqrt(.Machine[["double.eps"]]))
+       trans_tol = sqrt(.Machine[["double.eps"]]),
+       sym_tol = sqrt(.Machine[["double.eps"]]),
+       sym_tol1 = 8*sqrt(.Machine[["double.eps"]]))
 }
\ No newline at end of file
