@@ -1,5 +1,5 @@
 define_r <- function(n, p, res_order, gs_tol){
-  stopifnot(isPermutation(res_order), is.numeric(gs_tol), gs_tol > 0)
+  stopifnot(isOrdering(x = res_order, len = n), is.numeric(gs_tol), gs_tol > 0)
   # First create orthogonal vectors, then normalize.
   validate_numeric(n, len = 1, pos_int = TRUE)
   validate_numeric(p, len = 1, pos_int = TRUE)
