@@ -1,7 +1,7 @@
 distfreereg <-
   function(test_mean,
            ordering = "simplex",
-           group = FALSE,
+           group = TRUE,
            stat = c("KS", "CvM"),
            B = 1e4,
            control = NULL,
