@@ -1,7 +1,7 @@
 distfreereg.function <-
   function(test_mean,
            ordering = "simplex",
-           group = FALSE,
+           group = TRUE,
            stat = c("KS", "CvM"),
            B = 1e4,
            control = NULL,
@@ -12,6 +12,8 @@ distfreereg.function <-
            X = NULL,
            covariance,
            theta_init){
+    stopifnot(is.function(test_mean))
+    
     cl <- match.call()
     
     extra_arg_list <- list(...)
@@ -24,8 +26,8 @@ distfreereg.function <-
                                          extra_arg_list = extra_arg_list)
     Y <- vargs[["Y"]]; X <- vargs[["X"]]; n <- vargs[["n"]]; J <- vargs[["J"]]
     covariance = vargs[["covariance"]]; matsqrt_tol = vargs[["matsqrt_tol"]]
-    solve_tol = vargs[["solve_tol"]]; qr_tol <- vargs[["qr_tol"]]
-    orth_tol <- vargs[["orth_tol"]]; trans_tol <- vargs[["trans_tol"]]
+    solve_tol = vargs[["solve_tol"]]
+    # qr_tol <- vargs[["qr_tol"]]; orth_tol <- vargs[["orth_tol"]]; trans_tol <- vargs[["trans_tol"]]
     optimization_fun <- vargs[["optimization_fun"]]
     optimization_args <- vargs[["optimization_args"]]
     theta_hat_name <- vargs[["theta_hat_name"]]
@@ -50,7 +52,7 @@ distfreereg.function <-
                                             fun_to_optimize_arg = fun_to_optimize_arg)
       theta_hat <- optimization_output[[theta_hat_name]]
       if(is.null(theta_hat))
-        stop("No element with name \"", theta_hat_name, "\" found in optimization output")
+        stop("No element with name '", theta_hat_name, "' found in optimization output")
     } else {
       if(isTRUE(verbose)) message("Using supplied parameter estimates...")
       theta_hat <- override[["theta_hat"]]
@@ -60,6 +62,10 @@ distfreereg.function <-
     if(is.null(override[["fitted_values"]])){
       if(isTRUE(verbose)) message("Calculating fitted values...")
       fitted_values <- ftheta(theta_hat)
+      if(!is.vector(fitted_values)){
+        warning("fitted_values being coerced to a vector...")
+        fitted_values <- as.vector(fitted_values)
+      }
     } else {
       if(isTRUE(verbose)) message("Using supplied fitted values...")
       fitted_values <- override[["fitted_values"]]
@@ -76,9 +82,6 @@ distfreereg.function <-
       override[["J"]] <- NULL
     }
     
-    # Prevent verification of symmetry in further methods.
-    control[["symmetric"]] <- FALSE
-    
     # Remove elements of control and override that will not be used by default
     # method.
     for(var in c("jacobian_args", "optimization_fun", "fun_to_optimize_arg",
@@ -98,26 +101,17 @@ distfreereg.function <-
       call = cl,
       data = list(Y = Y, X = X),
       test_mean = test_mean,
-      covariance = covariance,
       theta_hat = theta_hat,
-      optimization_output = if(exists("optimization_output")) optimization_output else NULL,
-      fitted_values = fitted_values,
-      J = J,
-      mu = dfr_default_output[["mu"]],
-      r = dfr_default_output[["r"]],
-      r_tilde = dfr_default_output[["r_tilde"]],
-      residuals = list(raw = dfr_default_output[["residuals"]][["raw"]],
-                       sphered = dfr_default_output[["residuals"]][["sphered"]],
-                       transformed = dfr_default_output[["residuals"]][["transformed"]]),
-      res_order = dfr_default_output[["res_order"]],
-      aggregator_matrix = dfr_default_output[["aggregator_matrix"]],
-      epsp = dfr_default_output[["epsp"]],
-      observed_stats = dfr_default_output[["observed_stats"]],
-      mcsim_stats = dfr_default_output[["mcsim_stats"]],
-      p = list(value = dfr_default_output[["p"]][["value"]], mcse = dfr_default_output[["p"]][["mcse"]])
+      covariance = covariance,
+      optimization_output = if(exists("optimization_output")) optimization_output else NULL
     )
     
-    class(output) <- "distfreereg"
+    output <- combine_lists(output, dfr_default_output)
+    if(is(dfr_default_output[[length(dfr_default_output)]], "error")){
+      class(output) <- "distfreereg-error"
+    } else {
+      class(output) <- "distfreereg"
+    }
     
     return(output)
   }
