@@ -1,7 +1,7 @@
 generate_error_matrix <- function(err_dist_fun, err_dist_args, err_dist_fun_formals,
-                                  true_covariance, cov_args, solve_tol, reps, n){
+                                  true_covariance, cov_args, solve_tol, reps, n, ...){
   # Define error-generating function and argument list, then generate errors.
-  # err_dist_fun <- get(err_dist_fun)
+  # message("covariance list names: ", names(true_covariance))
   if(reps > 0){
     err_dist_args_default <-
       create_err_dist_args_default(err_dist_fun_formals = err_dist_fun_formals,
