@@ -1,18 +1,19 @@
 predict.distfreereg <-
-  function(object, ..., newdata){
+  function(object, ...){
     stopifnot(!is.null(object[["test_mean"]]))
     test_mean <- object[["test_mean"]]
-    if(missing(newdata)){
-      output <- fitted(object)
+    if(isModel(test_mean) || is(test_mean, "formula")){
+      if(is(test_mean, "formula")){
+        m <- object[["model"]]
+        stopifnot(!is.null(m))
+      } else {
+        m <- test_mean
+      }
+      output <- predict(m, ...)
     } else {
-      if(is(test_mean, "lm") || is(test_mean, "nls") || is(test_mean, "formula")){
-        if(is(test_mean, "formula")){
-          m <- object[["model"]]
-          stopifnot(!is.null(m))
-        } else {
-          m <- test_mean
-        }
-        output <- predict(m, ..., newdata = newdata)
+      newdata <- list(...)[["newdata"]]
+      if(is.null(newdata)){
+        output <- fitted(object)
       } else {
         if(is.function(test_mean)){
           stopifnot(!is.null(object[["theta_hat"]]))
@@ -21,7 +22,7 @@ predict.distfreereg <-
             warning("Vector supplied as 'newdata' converted into single row of newdata matrix...")
             newdata <- t(as.matrix(newdata))
           }
-          output <- f2ftheta(f = test_mean, X = newdata, n = ncol(newdata))(object[["theta_hat"]])
+          output <- unname(f2ftheta(f = test_mean, X = newdata, n = ncol(newdata))(object[["theta_hat"]]))
         }
       }
     }
