@@ -12,11 +12,11 @@ function(arg, choices){
   match_ind <- sapply(choices_internal, function(x) identical(arg, x))
   if(isFALSE(length(which(match_ind)) == 1)){
     if(is(choices, "compare")){
-      stop("\"", arg, "\" not found among statistics in compare object")
+      stop("'", arg, "' not found among statistics in compare object")
     } else {
       stop(deparse1(substitute(arg)), " must be exactly one of ",
-           paste0("\"", choices_internal, "\"", collapse = ", "),
-           "; it cannot be \"", arg, "\"")
+           paste0("'", choices_internal, "'", collapse = ", "),
+           "; it cannot be '", arg, "'")
     }
   }
 }
\ No newline at end of file
