@@ -1,5 +1,5 @@
 validate_args_distfreereg_default <-
-  function(Y, X, covariance, ordering, J, fitted_values, stat, B,
+  function(Y, X, covariance, ordering, J, fitted_values, stat, B, group,
            override, verbose, control, extra_arg_list){
     
     validate_extra_arg_list(extra_arg_list, "distfreereg.default()")
@@ -7,88 +7,71 @@ validate_args_distfreereg_default <-
     if(!is.null(control))
       validate_named_list(control, valid_names = c("matsqrt_tol", "solve_tol",
                                                    "qr_tol", "orth_tol",
-                                                   "trans_tol", "symmetric",
-                                                   "data"))
-
-    control <- combine_lists(control, default_distfreereg_tol())
+                                                   "trans_tol", "sym_tol",
+                                                   "sym_tol1",
+                                                   "return_on_error", "data"))
+    
+    control <- combine_lists(control,
+                             list(return_on_error = TRUE),
+                             default_distfreereg_tol())
     validate_control_tols(control)
     
-    symmetric <- control[["symmetric"]]
-    if(!isFALSE(symmetric) && !is.null(symmetric) && !is_named_list(symmetric))
-      stop("control element \"symmetric\" must be NULL, FALSE, or a named list")
-
-    # Verify that Y is numeric and has at least two entries.
-    if(!is.vector(Y)){
-      if(isTRUE(verbose)) message("Coercing Y to vector...")
-      Y <- tryCatch(as.vector(Y), error = function(e) stop("Error converting Y to a vector: ", e))
-    }
-    validate_numeric(x = Y, min_len = 2, message = "Y failed numeric validation: ")
+    return_on_error <- control[["return_on_error"]]
+    if(!isTRUE(return_on_error) && !isFALSE(return_on_error))
+      stop("control[['return_on_error']] must be TRUE or FALSE")
+    
+    Y <- validate_Y(Y = Y, verbose = verbose)
     n <- length(Y)
     
-    # Verify that X is numeric, and convert to a matrix in case it is just a
-    # vector.
-    if(!is.null(X)){
-      if(!is.matrix(X)){
-        if(isTRUE(verbose)) message("Coercing X to matrix...")
-        X <- tryCatch(as.matrix(X), error = function(e) stop("Error converting X to a matrix: ", e))
-      }
-      validate_numeric(x = X, message = "X failed numeric validation: ")
-      column_value_counts <- apply(X, MARGIN = 2, function(x) length(unique(x)))
-      if(!identical(colnames(X)[1], "(Intercept)") && isTRUE(any(column_value_counts == 1)))
-        warning("At least one column of X contains only one value. Verify that the model is identifiable.")
-    }
+    X <- validate_X(X = X, verbose = verbose)
     
     
     
     # Verify that override is a named list.
     if(!is.null(override)){
       validate_named_list(override, valid_names = c("res_order", "r", "mcsim_stats"))
-      if(!is.null(override[["dfr"]]) && !is(override[["dfr"]], "distfreereg"))
-        stop("override[[\"dfr\"]] must be an object of class 'distfreereg'")
       
       if(!is.null(override[["res_order"]])){
-        if(!isPermutation(override[["res_order"]])) stop("override[[\"res_order\"]] must be a permutation")
-        if(length(override[["res_order"]]) != n) stop("override[[\"res_order\"]] and Y must have the same length")
+        if(!isOrdering(override[["res_order"]], len = n)) stop("override[['res_order']] must be an ordering")
       }
       
       if(!is.null(override[["r"]])){
-        validate_numeric(override[["r"]], message = "Override r failed numeric validation: ")
-        if(nrow(as.matrix(override[["r"]])) != n) stop("nrow(as.matrix(override[[\"r\"]])) must be equal to length(Y)") 
+        validate_numeric(override[["r"]], message = "override[['r']] failed numeric validation: ")
+        if(nrow(as.matrix(override[["r"]])) != n) stop("nrow(as.matrix(override[['r']])) must be equal to length(Y)") 
       }
-      
-      if(!is.null(J) && !is.null(override[["r"]]) &&
-         !all(dim(as.matrix(J)) == dim(as.matrix(override[["r"]]))))
-        stop("as.matrix(override[[\"J\"]]) and as.matrix(override[[\"r\"]]) must have the same dimensions")
     }
     
     validate_numeric(J, message = "J failed numeric validation: ")
     J <- as.matrix(J)
     if(nrow(as.matrix(J)) != n) stop("nrow(as.matrix(J)) must be equal to length(Y)") 
-
+    
     validate_numeric(fitted_values, len = n,
                      message = "Fitted values failed numeric validation: ")
     
-
+    
     # Verify that X and Y dimensions match.
     if(!is.null(X) && nrow(X) != n)
       stop("The number of rows in X must be the length of Y: nrow(X) is ",
            nrow(X), ", but length(Y) is ", n)
     
     # Verify covariance list.
-    # covariance <- eval_cov(covariance_list = covariance, Y = Y, X = X)
-    validate_covariance_list(covariance, n = n, allow_function = FALSE,
-                             require_diagonal = FALSE, symmetric = symmetric)
+    validate_covariance_list(covariance, n = n, sym_tol = control[["sym_tol"]],
+                             sym_tol1 = control[["sym_tol1"]])
+    
     
-
     # Validate B
     validate_numeric(x = B, pos_int = TRUE, len = 1)
     B <- as.integer(B)
     
-
+    
     # Validate the observation ordering specification.
     if(is.null(override[["res_order"]])){
       if(is.list(ordering)){
-        validate_order_columns(X, ordering)
+        if(!is.null(control[["data"]])){
+          validate_order_columns(control[["data"]], ordering)
+        } else {
+          validate_order_columns(X, ordering)
+        }
       } else {
         if(length(ordering) > 1) stop("ordering method specification must have length one, ",
                                       "or be a list of column specifications")
@@ -96,6 +79,9 @@ validate_args_distfreereg_default <-
       }
     }
     
+    # Validate 'group'
+    if(!isTRUE(group) && !isFALSE(group)) stop("'group' must be TRUE or FALSE")
+
     # Check stat functions for egregious errors.
     v <- vector(mode = "list", length = length(stat))
     for(i in seq_along(stat)){
@@ -115,5 +101,9 @@ validate_args_distfreereg_default <-
     return(list(Y = Y, X = X, n = n, J = J, covariance = covariance,
                 matsqrt_tol = control[["matsqrt_tol"]], solve_tol = control[["solve_tol"]],
                 qr_tol = control[["qr_tol"]], orth_tol = control[["orth_tol"]],
-                trans_tol = control[["trans_tol"]], B = B))
+                trans_tol = control[["trans_tol"]],
+                sym_tol = control[["sym_tol"]],
+                sym_tol1 = control[["sym_tol1"]],
+                B = B,
+                return_on_error = return_on_error))
   }
