@@ -1,13 +1,13 @@
 validate_args_distfreereg_nls <-
   function(test_mean, n, control, extra_arg_list, verbose){
+    stopifnot(is(test_mean, "nls"))
     validate_extra_arg_list(extra_arg_list, "distfreereg.nls()")
-    if(!is(test_mean, "nls")) stop("test_mean must be an object of class \"nls\"")
     validate_single_response_term(form = test_mean)
     if(!is.null(control) && !is.list(control)) stop("'control' must be NULL or a list")
     if(!is.null(control))
       validate_named_list(control, valid_names = c("matsqrt_tol", "solve_tol",
                                                    "qr_tol", "orth_tol", "trans_tol",
-                                                   "symmetric", "data"))
+                                                   "data", "return_on_error"))
     control <- combine_lists(control, default_distfreereg_tol())
     validate_control_tols(control)
     
