@@ -16,7 +16,13 @@ vcov.distfreereg <- function(object, ..., jacobian_args = NULL, hessian_args = N
   } else {
     if(!is.null(jacobian_args) || !is.null(jacobian_args))
       warning("jacobian_args and/or hessian_args ignored when 'test_mean' is not a function")
-    output <- vcov(test_mean, ...)
+    if(is(test_mean, "formula")){
+      m <- object[["model"]]
+      stopifnot(!is.null(m))
+    } else {
+      m <- object[["test_mean"]]
+    }
+    output <- vcov(object = m, ...)
   }
   return(output)
 }
\ No newline at end of file
